@@ -274,10 +274,10 @@ static int
 	send_willcmd P((char *)),
 	send_wontcmd P((char *));
 
-void send_wont(int,int);
-void send_dont(int,int);
-void send_will(int,int);
-void send_do(int,int);
+void send_wont P((int,int));
+void send_dont P((int,int));
+void send_will P((int,int));
+void send_do   P((int,int));
 
 static struct sendlist Sendlist[] = {
     { "ao",	"Send Telnet Abort output",		1, 0, 0, 2, AO },
