@@ -1034,7 +1034,7 @@ telnet(f, p, host)
 	if (my_state_is_wont(TELOPT_ECHO))
 		send_will(TELOPT_ECHO, 1);
 
-#ifndef SOLARIS2
+#if !defined(SOLARIS2) && !defined(HPUX)
 	/*
 	 * Turn on packet mode
 	 */
